#!/usr/bin/python
"""StorPool cgtool."""

import argparse


from . import cgconf
from . import cgcheck
from . import cgprint


SCRIPTS = {'conf': cgconf, 'print': cgprint, 'check': cgcheck}


def get_args_parser():
    """Return command line arguments parser."""
    parser = argparse.ArgumentParser(description='StorPool cgroups tool')
    parser.add_argument('command', choices=SCRIPTS.keys())
    parser.add_argument('args', nargs=argparse.REMAINDER)
    return parser


SCRIPT_TEMPL = 'storpool_cg {command}'


def main():
    """
    Parse the first command line argument and dispatch to the requested
    tool's main function with the appropriate arguments.
    """
    parser = get_args_parser()
    args = parser.parse_args()
    script_name = SCRIPT_TEMPL.format(command=args.command)
    script = SCRIPTS[args.command]
    script.main([script_name] + args.args)


if __name__ == '__main__':
    main()
