"""Storpool cgcheck."""
from __future__ import print_function

import argparse
import json
import sys

from sp.validations import cgroups as cgchecks
from sp.cgroups import hierarchy
from sp import messages as m


def get_args():
    """Return the parsed command line arguments."""
    parser = argparse.ArgumentParser(description='StorPool cgroups checking',
                                     prog='storpool_cg check')
    parser.add_argument('-J', '--json', action='store_true', default=False,
                        help='Use json output.')

    return parser.parse_args()


def main(argv=None):
    """
    The main program: parse the command line arguments and check the current
    cgroups configuration for common problems.
    """
    if argv is not None:
        sys.argv = argv
    args = get_args()

    m.set_verbose_level(1)

    cpuset_info, memory_info = hierarchy.get().cpuset_memory_info()

    checks = {
        'cpuset': cgchecks.get_cpuset_check(cpuset_info),
        'memory': cgchecks.get_advanced_memory_check(memory_info),
    }

    json_report = {}

    has_errors = False
    has_warnings = False

    for name, check in checks.items():
        check.run()
        errors = check.get_all_errors()
        warnings = check.get_all_warnings()

        has_errors |= bool(errors)
        has_warnings |= bool(warnings)

        if args.json:
            json_report[name] = {'errors': errors, 'warnings': warnings}
        else:
            if errors or warnings:
                m.msg('==== {0} ===='.format(name))
            map(m.warn_msg, warnings)
            map(m.err_msg, errors)

    if args.json:
        print(json.dumps(json_report))

    if has_errors:
        sys.exit(1)
    if has_warnings:
        sys.exit(2)
    sys.exit(0)
