"""Create a cgtool configfile parser."""


import six

from sp import messages as m
from sp.util.backports import configparser


T = six.text_type
SECTION_NAME = T('cgtool')


def _add_parser_override(parser, option, value):
    parser.set(SECTION_NAME, T(option), T(value))


def _add_parser_overrides(parser, overrides):
    if overrides is None:
        return
    for option, value in overrides.items():
        _add_parser_override(parser, option, value)


def get_file_parser(configfile, overrides=None):
    """Returns a file parser for the given configfile, applying the given
    overrides. A parser sanity check is performed.
    """
    parser = configparser.ConfigParser()
    if configfile is not None:
        parser.read(configfile)
    if not parser.has_section(SECTION_NAME):
        parser.add_section(SECTION_NAME)

    _add_parser_overrides(parser, overrides)
    _parser_sanity(parser)
    return parser


OPTIONS = ['converged', 'block', 'iscsi', 'mgmt', 'bridge', 'servers',
           'set_cache_size', 'set_memsw', 'numa_overflow', 'system_limit',
           'user_limit', 'kernel_mem', 'machine_limit', 'sp_alloc_limit',
           'sp_common_limit', 'iface', 'iface_acc', 'cores', 'confdir',
           'cachedir']


def _parser_sanity(parser):
    if not parser.has_section(SECTION_NAME):
        m.exit_msg('No cgtool section found in config')

    for section in parser.sections():
        if section != SECTION_NAME:
            m.exit_msg('Unknown config section: {0}'.format(section))

    for option in parser.options(SECTION_NAME):
        if option not in OPTIONS:
            m.exit_msg('Unknown config option: {0}'.format(option))
