"""Provides human readable printing functions for some configurations."""

from __future__ import print_function


from sp import cpuinfo


def print_cpu_conf(cpu_to_service):
    """Human-readable print of the cpu-services configuration."""
    cpui = cpuinfo.get()
    max_cpu_digits = len(str(cpui.cpu_count() - 1))
    thread_tmpl = '{0:' + str(max_cpu_digits) + 'd}'
    for socket in cpui.socket_ids():
        print("socket:{0}".format(socket))
        for core, threads in cpui.socket_info(socket).items():
            threads_str = ','.join(thread_tmpl.format(thread)
                                   for thread in sorted(threads))
            cpu_ser = ['{0} - {1}'.format(t, ','.join(cpu_to_service[t]))
                       for t in sorted(threads) if t in cpu_to_service]
            info = ' <--- {0}'.format('; '.join(cpu_ser)) if cpu_ser else ''
            print("  core:{core:2d} cpu:{cpus}{info}"
                  .format(core=core, cpus=threads_str, info=info))


def print_mem_conf(slice_limits):
    """Human-readable print of the slices memory configuration."""
    for slc, limit in sorted(slice_limits.items()):
        if slc == 'storpool':
            print('slice: storpool limit: {0}'.format(limit['all']))
            print('  subslice: storpool/common limit: {0}'
                  .format(limit['common']))
            print('  subslice: storpool/alloc limit: {0}'
                  .format(limit['alloc']))
        else:
            print('slice: {0} limit: {1}'.format(slc, limit))
