"""Utils for gathering information about the current installed services."""

import collections


from sp.cgroups import filters
from sp.util.misc import list2d_flatten


def current_cpu_to_service(cpuset_info):
    """Creates cpu-services dictionary from cpuset info."""
    cpu_to_s = collections.defaultdict(list)
    for grp in cpuset_info:
        if filters.is_sp_subgroup(grp):
            cpu = cpuset_info[grp]['cpuset.cpus'][0]
            service = grp.split('/')[1]
            cpu_to_s[cpu].append(service)
    return dict(cpu_to_s.items())


def current_services(cpuset_info):
    """Creates list of current sp services from cpuset info."""
    return list2d_flatten(current_cpu_to_service(cpuset_info).values())
